async fn bound_range<R, D>(
ds: &D,
range: R,
) -> impl RangeBounds<usize> + use<R, D>Expand description
Apply an upper bound to a range based on the currently available block height.
async fn bound_range<R, D>(
ds: &D,
range: R,
) -> impl RangeBounds<usize> + use<R, D>Apply an upper bound to a range based on the currently available block height.